==> semantik_0.6.5.orig.tar.gz: semantik-0.6.5.orig/src/Flult.h <==
/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef feluh
#define feluh

#include <QtGui/QGraphicsView>
#include  <QGraphicsRectItem>
#include   <QVector>
#include    <QMap>
#include     <QList>
#include      "con.h"
#include       <QAction> 

class QMenu;
class izlt;
class jelzpn;
class rslt;
class felu : public QGraphicsView
<%
	Q_OBJECT
	public:
		felu(QWidget *irnyjl, jelzpn* megkap);
		void ceco();

		QMap<int, rslt*> kket;

		enum fajta
		<%
			mzgat = 0,
			meghat = 1,
			tiszta = 2,
			ugyex = 3,
			munka = 4,
		%>;

		void eler(fajta tqrost);

		QMenu* alkt;
		QMenu* korrkt;
		QMenu* jo;

		fajta ir;

		void keyPressEvent(QKeyEvent *jlnrdz);
		void keyReleaseEvent(QKeyEvent *jlnrdz);
		void focusOutEvent(QFocusEvent *mgmnkl);
		void wheelEvent(QWheelEvent *jlnrdz);
		void mouseDoubleClickEvent(QMouseEvent *mgmnkl);
		void mousePressEvent(QMouseEvent *mgmnkl);
		void mouseMoveEvent(QMouseEvent *mgmnkl);
		void mouseReleaseEvent(QMouseEvent *mgmnkl);
		void focusInEvent(QFocusEvent *mgmnkl);

		bool nybnvn;
		QPoint ellqts;
		QPointF kitzjl;

		QWidget *nagy;

		QGraphicsRectItem * kiallt;
		QGraphicsLineItem * lemasl;
		QList<rslt*> hzzqjt;

		void elodez(bool csals=1);
		void gyrtmn(int lnmtat, bool fnqll);
		void lmzdul(rslt*, bool csals=1);
		void elktzk(rslt*, bool csals=1);
		void fhlhjt(bool csals=1);
		void lep(); 

		void detto();

		jelzpn *kidlgz;

		QVector<rslt*> lecke;

		QPointF vmrgem;

		int muri;

		void kivitl(int mozog, int tljsn);

		fajta megir;

		void hsztzk();

		bool event(QEvent *jlnrdz);

		void sima(bool);

		QAction *dolog;
		QAction *akdaly;
		QAction *zandek;

	public slots:
		void kelt(const zagv&);
		void mgzerz(QAction*);
		void mgmozt();
		void kapod(QAction*);
		void cel();
		void fladat();
		void kltzik(); 
		void kitolt();
		void targy();
		void amkzrs();
		void marka();
		void kesztm();
		void zoom_in();
		void zoom_out();

		void kapni();

	signals:
		void jvsltz(const QString &, int);
%>;

#endif

==> semantik_0.6.8.orig.tar.gz: semantik-0.6.8.orig/src/Flult.h <==
/// Copyright Thomas Nagy 2007
/// License: QPL
#ifndef feluh
#define feluh

#include <QtGui/QGraphicsView>
#include  <QGraphicsRectItem>
#include   <QVector>
#include    <QMap>
#include     <QList>
#include      "con.h"
#include       <QAction> 

class QMenu;
class izlt;
class jelzpn;
class rslt;
class felu : public QGraphicsView
<%
	Q_OBJECT
	public:
		felu(QWidget *irnyjl, jelzpn* megkap);
		void ceco();

		QMap<int, rslt*> kket;

		enum fajta
		<%
			mgmozt = 0,
			meghat = 1,
			tljsn = 2,
			tiszta = 3,
			ugyex = 4,
		%>;

		void eler(fajta tqrost);

		QMenu* alkt;
		QMenu* korrkt;
		QMenu* jo;

		fajta ir;

		void keyPressEvent(QKeyEvent *jlnrdz);
		void keyReleaseEvent(QKeyEvent *jlnrdz);
		void focusOutEvent(QFocusEvent *mgmnkl);
		void wheelEvent(QWheelEvent *jlnrdz);
		void mouseDoubleClickEvent(QMouseEvent *mgmnkl);
		void mousePressEvent(QMouseEvent *mgmnkl);
		void mouseMoveEvent(QMouseEvent *mgmnkl);
		void mouseReleaseEvent(QMouseEvent *mgmnkl);
		void focusInEvent(QFocusEvent *mgmnkl);

		bool nybnvn;
		QPoint ellqts;
		QPointF kitzjl;

		QWidget *nagy;

		QGraphicsRectItem * kiallt;
		QGraphicsLineItem * lemasl;
		QList<rslt*> hzzqjt;

		void elodez(bool lecke=1);
		void gyrtmn(int lnmtat, bool fnqll);
		void lmzdul(rslt*, bool lecke=1);
		void elktzk(rslt*, bool lecke=1);
		void muri(bool lecke=1);
		void lep(); 

		void detto();

		jelzpn *kidlgz;

		QVector<rslt*> csals;

		QPointF vmrgem;

		int fhlhjt;

		void kivitl(int mzgat, int sima);

		fajta megir;

		void hsztzk();

		bool event(QEvent *jlnrdz);

		void munka(bool);

		QAction *dolog;
		QAction *akdaly;
		QAction *zandek;

	public slots:
		void kelt(const zagv&);
		void mgzerz(QAction*);
		void rabir();
		void kapod(QAction*);
		void cel();
		void fladat();
		void kltzik(); 
		void kitolt();
		void targy();
		void amkzrs();
		void marka();
		void kesztm();
		void zoom_in();
		void zoom_out();

		void kapni();

	signals:
		void jvsltz(const QString &, int);
%>;

#endif
